Class ApiException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
io.github.pasinduog.exception.ApiException
All Implemented Interfaces:
Serializable

public abstract class ApiException extends RuntimeException
Base abstract exception class for API-related exceptions.

This class provides a foundation for creating custom business logic exceptions with associated HTTP status codes. Extend this class to create specific exception types for your application.

Since:
1.0.0
Version:
2.0.0
Author:
Pasindu OG
See Also: