Class ApiException

All Implemented Interfaces:
Serializable

public abstract class ApiException extends RuntimeException
Base abstract exception class for API-related exceptions.

This class provides a foundation for creating custom business logic exceptions with associated HTTP status codes. Extend this class to create specific exception types for your application.

Since:
1.0.0
Version:
2.0.0
Author:
Pasindu OG
See Also:
  • Method Details

    • getStatus

      public org.springframework.http.HttpStatus getStatus()
      Gets the HTTP status code associated with this exception.
      Returns:
      the HTTP status